package se.su.dsv.scipro.date;


import com.google.inject.persist.Transactional;
import se.su.dsv.scipro.data.enums.DateStyle;
import se.su.dsv.scipro.system.AbstractServiceImpl;

import javax.inject.Inject;
import javax.inject.Provider;
import javax.persistence.EntityManager;
import java.text.SimpleDateFormat;
import java.util.Date;

public class DateServiceImpl extends AbstractServiceImpl<DateSetting,DateStyle> implements DateService {

    @Inject
    public DateServiceImpl(Provider<EntityManager> em) {
        super(em, DateSetting.class, QDateSetting.dateSetting);
    }

    @Override
    public DateSetting findOne(DateStyle dateStyle) {
        DateSetting setting = super.findOne(dateStyle);
        if (setting == null) {
            setting = new DateSetting();
            setting.setStyle(dateStyle);
        }
        return setting;
    }

    @Override
    public String format(Date date) {
        return format(date, DateStyle.DATE);
    }

    @Override
    public String format(Date date, DateStyle style) {
        DateSetting setting = findOne(style);
        SimpleDateFormat dateFormat = new SimpleDateFormat(setting.getFormat());
        return dateFormat.format(date);
    }

    @Override
    @Transactional
    public DateSetting saveFormat(String format, DateStyle style) {
        DateSetting setting = findOne(style);
        setting.setFormat(format);
        return save(setting);
    }

    @Override
    public String getFormat(DateStyle style) {
        return findOne(style).getFormat();
    }
}
