package se.su.dsv.scipro.date;

import org.junit.Assert;
import org.junit.Test;
import se.su.dsv.scipro.data.enums.DateStyle;
import se.su.dsv.scipro.test.IntegrationTest;

import javax.inject.Inject;
import java.util.Date;

import static org.junit.Assert.assertEquals;

public class DateServiceImplTest extends IntegrationTest {

    @Inject
    private DateServiceImpl service;

    @Test
    public void testFormat() throws Exception {
        // given
        DateSetting setting = new DateSetting();
        setting.setFormat("yyyy-MM-dd");
        setting.setStyle(DateStyle.DATE);
        save(setting);

        // when
        String date = service.format(new Date());

        // then
        Assert.assertNotNull(date);
    }

    @Test
    public void testFormatWithNullSetting() throws Exception {
        // given

        // when
        String date = service.format(new Date());

        // then
        Assert.assertNotNull(date);
    }

    @Test
    public void testSaveFormat() throws Exception {
        // given
        String format = "yyyy-MM-dd";
        DateStyle style = DateStyle.DATE;

        // when
        service.saveFormat(format, style);

        // then

        DateSetting setting = service.findOne(style);
        assertEquals(setting.getFormat(), format);
        assertEquals(setting.getStyle(), style);
    }

    @Test
    public void testGetFormat() throws Exception {
        // given
        String format = "yy/MM/dd";
        DateSetting setting = new DateSetting();
        setting.setStyle(DateStyle.DATE);
        setting.setFormat(format);
        save(setting);

        // when
        String persistedFormat = service.getFormat(DateStyle.DATE);

        // then
        Assert.assertEquals(format, persistedFormat);
    }
}
