package se.su.dsv.scipro.integration.daisy;

import com.google.common.base.Function;
import com.google.common.base.Predicate;
import com.google.common.collect.FluentIterable;
import se.su.dsv.scipro.io.dto.Person;
import se.su.dsv.scipro.io.http.DaisyAPI;
import se.su.dsv.scipro.security.auth.roles.Roles;
import se.su.dsv.scipro.system.User;
import se.su.dsv.scipro.system.UserSearchService;
import se.su.dsv.scipro.system.UserService;

import javax.inject.Inject;
import java.util.Collection;
import java.util.Collections;

class DaisyUserSearchService implements UserSearchService {
    private final DaisyAPI daisyAPI;
    private final UserService userService;

    @Inject
    DaisyUserSearchService(final DaisyAPI daisyAPI, final UserService userService) {
        this.daisyAPI = daisyAPI;
        this.userService = userService;
    }

    @Override
    public Collection<User> search(final String term, final Roles role, final long maxResults) {
        if (term != null && term.length() > 5) {
            return FluentIterable.from(daisyAPI.findByPersonnummer(term))
                    .transform(new Function<Person, User>() {
                        @Override
                        public User apply(final Person person) {
                            return userService.findByExternalIdentifier(person.getId());
                        }
                    })
                    .filter(User.class) // Filter out nulls
                    .filter(new Predicate<User>() {
                        @Override
                        public boolean apply(final User user) {
                            return user.hasRole(role);
                        }
                    })
                    .toList();
        }
        return Collections.emptyList();
    }
}
