package se.su.dsv.scipro.basepages.errorpages;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.AjaxFallbackLink;
import org.apache.wicket.markup.html.basic.Label;
import se.su.dsv.scipro.basepages.MenuPage;

/**
 * Base class for errors capable of rendering "most parts" of the system correctly, intended for subclass-specialization.
 * See "CustomErrorPage" and it's sub types for suitable examples on how to use this class for custom error messages.
 */
abstract class AbstractErrorPage extends MenuPage {

    AbstractErrorPage(final String message) {
        setVersioned(false);

        final Label errorDetails = new Label("errorDetails", message);
        errorDetails.setOutputMarkupPlaceholderTag(true);
        errorDetails.setVisible(false);
        add(errorDetails);

        add(new AjaxFallbackLink<String>("detailsLink") {
            @Override
            public void onClick(AjaxRequestTarget target) {
                if (target != null) {
                    target.add(errorDetails);
                }
                errorDetails.setVisible(!errorDetails.isVisible());
            }
        });
    }

    @Override
    public boolean isErrorPage() {
        return true;
    }
}
