package se.su.dsv.scipro.date;

import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.markup.html.form.Form;
import org.apache.wicket.markup.html.form.RequiredTextField;
import org.apache.wicket.markup.html.list.ListItem;
import org.apache.wicket.markup.html.list.ListView;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.LoadableDetachableModel;
import org.apache.wicket.model.StringResourceModel;
import se.su.dsv.scipro.admin.pages.AbstractAdminSystemPage;
import se.su.dsv.scipro.data.enums.DateStyle;

import javax.inject.Inject;
import java.util.Arrays;

public class AdminDateSettingsPage extends AbstractAdminSystemPage {

    static final String FORM = "form";
    static final String SETTINGS = "settings";
    static final String LABEL = "label";
    static final String FORMAT = "format";

    @Inject
    private DateService dateService;

    public AdminDateSettingsPage() {
        add(new SettingsForm(FORM));
    }

    private class SettingsForm extends Form<Void> {

        public SettingsForm(String id) {
            super(id);

            add(new ListView<DateStyle>(SETTINGS, Arrays.asList(DateStyle.values())) {
                @Override
                protected void populateItem(ListItem<DateStyle> item) {
                    item.add(new Label(LABEL, new StringResourceModel("${name}.description", this, item.getModel())));
                    item.add(new RequiredTextField<>(FORMAT, new DateFormatModel(item.getModel())));
                }
            });
        }

        @Override
        protected void onSubmit() {
            info("Date settings saved");
        }
    }

    private class DateFormatModel extends LoadableDetachableModel<String> {
        private final IModel<DateStyle> dateStyleIModel;

        public DateFormatModel(IModel <DateStyle> dateStyleIModel) {
            this.dateStyleIModel = dateStyleIModel;
        }

        @Override
        protected String load() {
            return dateService.getFormat(dateStyleIModel.getObject());
        }

        @Override
        public void setObject(String object) {
            dateService.saveFormat(object, dateStyleIModel.getObject());
            detach();
        }

        @Override
        public void onDetach() {
            dateStyleIModel.detach();
        }
    }
}
