package se.su.dsv.scipro.finalseminar;

import org.apache.wicket.RestartResponseException;
import org.apache.wicket.feedback.FencedFeedbackPanel;
import org.apache.wicket.markup.html.panel.EmptyPanel;
import org.apache.wicket.model.IModel;
import org.apache.wicket.request.mapper.parameter.PageParameters;
import org.apache.wicket.util.string.StringValue;
import se.su.dsv.scipro.components.menuhighlighting.MenuHighlightAuthorFinalSeminars;
import se.su.dsv.scipro.data.DetachableServiceModel;
import se.su.dsv.scipro.project.Project;
import se.su.dsv.scipro.project.ProjectService;
import se.su.dsv.scipro.project.pages.ProjectPage;
import se.su.dsv.scipro.util.PageParameterKeys;

import javax.inject.Inject;

public class ProjectFinalSeminarDetailsPage extends ProjectPage implements MenuHighlightAuthorFinalSeminars {

    public static final String SEMINAR_PANEL = "seminarPanel";
    public static final String WITHIN_PROJECT_KEY = "wp";
    public static final String FEEDBACK = "feedback";

    @Inject
    private FinalSeminarService finalSeminarService;
    @Inject
    private ProjectService projectService;

    public ProjectFinalSeminarDetailsPage(final PageParameters pp) {
        DetachableServiceModel<FinalSeminar> seminarModel = new DetachableServiceModel<>(finalSeminarService, getSeminarFromProject(pp));

        add(new FencedFeedbackPanel(FEEDBACK, this));
        add(new SeminarPanel(SEMINAR_PANEL, seminarModel));
    }

    public ProjectFinalSeminarDetailsPage(IModel<FinalSeminar> seminarModel) {
        add(new EmptyPanel(FEEDBACK));
        add(new SeminarPanel(SEMINAR_PANEL, seminarModel));
    }

    private FinalSeminar getSeminarFromProject(PageParameters pp) {
        StringValue projectId = pp.get(PageParameterKeys.MAP.get(Project.class));
        if (!projectId.isNull()) {
            Project project = projectService.findOne(projectId.toLong());
            if (project != null) {
                return finalSeminarService.findByProject(project);
            }
        }
        throw new RestartResponseException(getApplication().getHomePage());
    }
}
