package se.su.dsv.scipro.finalseminar;

import org.apache.wicket.Page;
import org.apache.wicket.model.Model;
import org.apache.wicket.request.mapper.parameter.PageParameters;
import org.junit.Test;
import org.mockito.Matchers;
import org.mockito.Mockito;
import se.su.dsv.scipro.SciProTest;
import se.su.dsv.scipro.admin.pages.AdminStartPage;
import se.su.dsv.scipro.project.Project;
import se.su.dsv.scipro.system.*;
import se.su.dsv.scipro.test.DomainObjects;
import se.su.dsv.scipro.util.PageParameterKeys;

import java.util.Date;

public class ProjectFinalSeminarDetailsPageTest extends SciProTest {

    private FinalSeminar finalSeminar;

    @Test
    public void renders() throws Exception {
        mockProjectAndSeminar();
        tester.startPage(new ProjectFinalSeminarDetailsPage(Model.of(finalSeminar)));
        assertRendering(ProjectFinalSeminarDetailsPage.class);
    }

    @Test
    public void renders_with_page_parameters() throws Exception {
        mockProjectAndSeminar();
        tester.startPage(ProjectFinalSeminarDetailsPage.class, getPageParameters());
        assertRendering(ProjectFinalSeminarDetailsPage.class);
    }

    @Test
    public void invalid_parameters_redirects() throws Exception {
        tester.startPage(ProjectFinalSeminarDetailsPage.class, getPageParameters());
        assertRendering(AdminStartPage.class);
    }

    @Test
    public void no_parameters_redirects() throws Exception {
        tester.startPage(ProjectFinalSeminarDetailsPage.class);
        assertRendering(AdminStartPage.class);
    }

    private PageParameters getPageParameters( ) {
        PageParameters parameters = new PageParameters();
        parameters.set(PageParameterKeys.MAP.get(Project.class), "1");
        parameters.set(ProjectFinalSeminarDetailsPage.WITHIN_PROJECT_KEY, "2");
        return parameters;
    }

    private void assertRendering(Class<? extends Page> expectedRenderedPageClass) {
        tester.assertRenderedPage(expectedRenderedPageClass);
        tester.assertNoErrorMessage();
    }

    private void mockProjectAndSeminar() {
        ProjectType projectType = new ProjectType(DegreeLevel.FIRST_CYCLE, "Bachelor", "Bachelor");
        ProjectTypeSettings projectTypeSettings = new ProjectTypeSettings();
        projectTypeSettings.setMaxFinalSeminarActiveParticipation(1);
        projectTypeSettings.setMaxOpponentsOnFinalSeminar(1);
        projectType.setProjectTypeSettings(projectTypeSettings);

        User supervisor = User.builder().firstName("Bob").lastName("Sponge").emailAddress("bob@example.com").build();
        Project project = Project.builder().title("bla").projectType(projectType).headSupervisor(supervisor).build();
        project.setId(23542L);

        finalSeminar = new FinalSeminar();
        finalSeminar.setProject(project);
        finalSeminar.setStartDate(new Date());
        DomainObjects.injectId(finalSeminar, 1L);

        Mockito.when(projectService.findOne(Matchers.anyLong())).thenReturn(project);
        Mockito.when(finalSeminarService.findByProject(Matchers.any(Project.class))).thenReturn(finalSeminar);
        Mockito.when(finalSeminarService.findOne(Matchers.anyLong())).thenReturn(finalSeminar);
        Mockito.when(finalSeminarSettingsService.getInstance()).thenReturn(new FinalSeminarSettings());
    }
}
