package se.su.dsv.scipro.statistics;

import org.apache.wicket.Page;
import org.joda.time.Instant;
import org.junit.Before;
import org.junit.Test;
import se.su.dsv.scipro.PageTest;
import se.su.dsv.scipro.file.FileDescription;
import se.su.dsv.scipro.misc.DaysService;
import se.su.dsv.scipro.project.Project;
import se.su.dsv.scipro.reviewing.Decision;
import se.su.dsv.scipro.reviewing.ReviewerDeadlineSettings;
import se.su.dsv.scipro.reviewing.RoughDraftApproval;
import se.su.dsv.scipro.system.DegreeLevel;
import se.su.dsv.scipro.system.ProjectType;
import se.su.dsv.scipro.util.Pair;

import java.util.Arrays;

import static org.mockito.Matchers.any;
import static org.mockito.Matchers.anyInt;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

public class AdminReviewerDeadlinesPageTest extends PageTest {

    @Before
    public void setUp() throws Exception {
        final ProjectType bachelor = new ProjectType(DegreeLevel.FIRST_CYCLE, "Bachelor", "Bachelor");
        final Project project = Project.builder().title("Test project").projectType(bachelor).build();
        final RoughDraftApproval roughDraftApproval = new RoughDraftApproval(project, new FileDescription(),"test");

        Decision decision = mock(Decision.class);
        when(decision.getDeadline(any(DaysService.class), anyInt())).thenReturn(Instant.now());
        when(reviewerDeadlineFollowupService.getLateRoughDrafts()).thenReturn(Arrays.asList(new Pair<>(roughDraftApproval, decision)));
        when(reviewerDeadlineSettingsService.getInstance()).thenReturn(new ReviewerDeadlineSettings());

        startPage();
    }

    @Test
    public void lists_all_rough_draft_deadlines_that_are_missed() throws Exception {
        tester.assertListView("roughDrafts", reviewerDeadlineFollowupService.getLateRoughDrafts());
    }

    @Test
    public void lists_all_final_seminar_approval_deadlines_that_are_missed() throws Exception {
        tester.assertListView("finalSeminarApprovals", reviewerDeadlineFollowupService.getLateFinalSeminarApprovals());
    }

    @Override
    protected Class<? extends Page> getPage() {
        return AdminReviewerDeadlinesPage.class;
    }
}